#editable-toolbar {
	position: fixed;
	top: 100px;
	left: 0;
	z-index: 9999;
}

#editable-toolbar a,
#editable-toolbar span,
.admin-feature-link {
	text-decoration: none;
	color: #222 !important;
	font-family: 'Roboto Condensed', sans-serif !important;
	font-size: 11px !important;
	font-weight: normal;
	text-transform: uppercase;
	background: #fffcc3;
	float: left;
	cursor: pointer;
	padding: 6px 8px;
	white-space: nowrap;
	line-height: 1em;
	border: .5px solid #ccc;
}

.admin-feature-link {
	position: absolute;
	top: 0;
	left: -32px;
}

.admin-link-icon {
	padding: 3px 3px 4px 3px !important;
}