{% load i18n static %}
<div id="editable-toolbar">
    <form class="success" id="logout-form" action="{% url 'lite_cms_core:logout' %}" method="post">
        {% csrf_token %}
        <a class="admin-link" href="#" onclick="document.getElementById('logout-form').submit();">
            {% trans 'Log out' %}
        </a>
        <a class="admin-link" href="/admin/">{% trans 'Admin' %}</a>
        {% if admin_edit_link %}
            <a class="admin-link" href="{{ admin_edit_link }}" >
                {% trans 'Edit in Admin' %}
            </a>
        {% endif %}
        <span class="show-toolbar admin-link-icon" style="display: none;">
            <img src="{% static 'lite_cms_core/icons/chevron-right.svg' %}" alt="">
        </span>
        <span class="hide-toolbar admin-link-icon">
            <img src="{% static 'lite_cms_core/icons/chevron-left.svg' %}" alt="">
        </span>
    </form>
</div>